"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.MonthPage = void 0;
exports.useCalendarContext = useCalendarContext;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _dateFns = require("date-fns");

var _lodash = require("lodash");

var _reactNativeInfinitePager = _interopRequireDefault(require("react-native-infinite-pager"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const DEFAULT_FONT_FAMILY = _reactNative.Platform.OS === "ios" ? "Helvetica Neue" : "sans-serif";
const DEFAULT_FONT_COLOR_ACTIVE = "black";
const DEFAULT_FONT_COLOR_INACTIVE = "gray";
const DEFAULT_THEME = {
  todayIndicatorDotColor: "tomato",
  selectedDayBackgroundColor: "rgba(0, 0, 255, 0.25)",
  selectedDayFontColor: DEFAULT_FONT_COLOR_ACTIVE,
  headerFontFamily: DEFAULT_FONT_FAMILY,
  headerFontColor: DEFAULT_FONT_COLOR_ACTIVE,
  headerFontSize: 24,
  headerTextTransform: "capitalize",
  headerDateFormat: "MMMM yyyy",
  dayLabelFontFamily: DEFAULT_FONT_FAMILY,
  dayLabelColor: DEFAULT_FONT_COLOR_ACTIVE,
  dayLabelFontSize: 12,
  dayLabelTextTransform: "uppercase",
  dayLabelDateFormat: "EEEEEE",
  dayFontFamily: DEFAULT_FONT_FAMILY,
  dayFontColor: DEFAULT_FONT_COLOR_ACTIVE,
  dayInactiveFontColor: DEFAULT_FONT_COLOR_INACTIVE,
  daySelectedFontColor: DEFAULT_FONT_COLOR_ACTIVE,
  dayFontSize: 12,
  inactiveOpacity: 1
};

const CalendarContext = /*#__PURE__*/_react.default.createContext({
  referenceDate: new Date(),
  selectedDate: null,
  onDateSelect: () => {},
  DayComponent: undefined,
  DayLabelComponent: undefined,
  HeaderComponent: undefined,
  theme: DEFAULT_THEME,
  pageInterpolator: defaultPageInterpolator
});

function useCalendarContext() {
  return (0, _react.useContext)(CalendarContext);
}

function defaultPageInterpolator({
  focusAnim,
  theme,
  pageWidth
}) {
  "worklet";

  return {
    transform: [{
      translateX: (0, _reactNativeReanimated.interpolate)(focusAnim.value, [-1, 0, 1], [-pageWidth.value, 0, pageWidth.value])
    }],
    opacity: (0, _reactNativeReanimated.interpolate)(focusAnim.value, [-1, 0, 1], [theme.inactiveOpacity, 1, theme.inactiveOpacity])
  };
}

const MonthPage = /*#__PURE__*/_react.default.memo(({
  index
}) => {
  const {
    referenceDate,
    HeaderComponent,
    DayLabelComponent,
    theme
  } = useCalendarContext();
  const firstDayOfMonth = (0, _react.useMemo)(() => (0, _dateFns.addMonths)(referenceDate, index), [referenceDate, index]);
  firstDayOfMonth.setDate(1);
  const lastDayOfMo = (0, _react.useMemo)(() => (0, _dateFns.lastDayOfMonth)(firstDayOfMonth), [firstDayOfMonth]);
  const headerText = (0, _dateFns.format)(firstDayOfMonth, theme.headerDateFormat);
  const weekStarts = (0, _react.useMemo)(() => (0, _dateFns.eachWeekOfInterval)({
    start: firstDayOfMonth,
    end: lastDayOfMo
  }), [firstDayOfMonth, lastDayOfMo]);
  const weeks = (0, _react.useMemo)(() => weekStarts.map(week => {
    return (0, _dateFns.eachDayOfInterval)({
      start: week,
      end: (0, _dateFns.addDays)(week, 6)
    });
  }), [weekStarts]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, null, HeaderComponent ? /*#__PURE__*/_react.default.createElement(HeaderComponent, {
    date: firstDayOfMonth
  }) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      alignItems: "center"
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: {
      fontSize: theme.headerFontSize,
      fontFamily: theme.headerFontFamily,
      color: theme.headerFontColor,
      textTransform: theme.headerTextTransform
    }
  }, headerText)), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.row
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.dayLabelRow
  }, weeks[0].map(day => {
    const dayLabelText = (0, _dateFns.format)(day, theme.dayLabelDateFormat);
    return DayLabelComponent ? /*#__PURE__*/_react.default.createElement(DayLabelComponent, {
      date: day
    }) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      key: `day-label-${day.toISOString()}`,
      style: styles.dayLabelContainer
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: {
        color: theme.dayLabelColor,
        fontFamily: theme.dayLabelFontFamily,
        fontSize: theme.dayLabelFontSize,
        textTransform: theme.dayLabelTextTransform
      }
    }, dayLabelText));
  }))), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: styles.row
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: {
      flex: 1
    }
  }, weeks.map(daysInWeek => {
    var _daysInWeek$;

    return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
      key: `week-${(_daysInWeek$ = daysInWeek[0]) === null || _daysInWeek$ === void 0 ? void 0 : _daysInWeek$.toISOString()}`,
      style: styles.weekContainer
    }, daysInWeek.map(day => {
      const sameMonth = (0, _dateFns.isSameMonth)(day, firstDayOfMonth);
      const dayDateFormatted = (0, _dateFns.format)(day, "yyyy-MM-dd");
      return /*#__PURE__*/_react.default.createElement(DayWrapper, {
        key: dayDateFormatted,
        isInDisplayedMonth: sameMonth,
        date: day,
        dateFormatted: dayDateFormatted
      });
    }));
  }))));
});

exports.MonthPage = MonthPage;

const DayWrapper = /*#__PURE__*/_react.default.memo(({
  date,
  isInDisplayedMonth,
  dateFormatted
}) => {
  const dateRef = (0, _react.useRef)(date);
  const memoDate = (0, _react.useMemo)(() => {
    if ((0, _dateFns.isSameDay)(dateRef.current, date)) {
      return dateRef.current;
    } else {
      dateRef.current = date;
      return date;
    }
  }, [date]);
  const {
    selectedDate,
    onDateSelect,
    DayComponent,
    theme
  } = useCalendarContext();
  const isSelected = (0, _react.useMemo)(() => {
    return !!selectedDate && (0, _dateFns.isSameDay)(memoDate, selectedDate);
  }, [memoDate, selectedDate]);
  const isToday = (0, _react.useMemo)(() => (0, _dateFns.isSameDay)(memoDate, new Date()), [memoDate]);
  const onDateSelectRef = (0, _react.useRef)(onDateSelect);
  onDateSelectRef.current = onDateSelect;
  const onDateSelectCb = (0, _react.useCallback)((date, options) => {
    var _onDateSelectRef$curr;

    return (_onDateSelectRef$curr = onDateSelectRef.current) === null || _onDateSelectRef$curr === void 0 ? void 0 : _onDateSelectRef$curr.call(onDateSelectRef, date, options);
  }, []);
  return /*#__PURE__*/_react.default.createElement(DayItem, {
    date: memoDate,
    dateFormatted: dateFormatted,
    isSelected: isSelected,
    isToday: isToday,
    isInDisplayedMonth: isInDisplayedMonth,
    DayComponent: DayComponent,
    onDateSelect: onDateSelectCb,
    theme: theme
  });
});

const DayItem = /*#__PURE__*/_react.default.memo(({
  date,
  isInDisplayedMonth,
  isSelected,
  DayComponent,
  isToday,
  onDateSelect,
  theme,
  dateFormatted
}) => {
  const dayText = (0, _dateFns.format)(date, "d");
  const deselectedColor = isInDisplayedMonth ? theme.dayFontColor : theme.dayInactiveFontColor;
  const color = isSelected ? theme.daySelectedFontColor : deselectedColor;

  if (DayComponent) {
    return /*#__PURE__*/_react.default.createElement(DayComponent, {
      date: date,
      isInDisplayedMonth: isInDisplayedMonth,
      isSelected: isSelected,
      isToday: isToday
    });
  }

  const padding = 10;
  return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    testID: `react-native-swipe-calendar:${dateFormatted}`,
    onPress: () => onDateSelect === null || onDateSelect === void 0 ? void 0 : onDateSelect(date, {
      isSelected
    }),
    style: {
      flex: 1,
      justifyContent: "center",
      alignItems: "center",
      flexDirection: "row",
      padding
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      flex: 0,
      aspectRatio: 1,
      position: "absolute",
      top: 0,
      bottom: 0,
      backgroundColor: isSelected ? theme.selectedDayBackgroundColor : "transparent",
      borderRadius: 5
    }
  }), /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: {
      color,
      fontSize: theme.dayFontSize,
      fontFamily: theme.dayFontFamily
    }
  }, dayText), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: {
      position: "absolute",
      width: 5,
      height: 5,
      bottom: padding / 2,
      borderRadius: 5,
      backgroundColor: isToday ? theme.todayIndicatorDotColor : "transparent"
    }
  }));
});

function Calendar({
  selectedDate,
  onDateSelect,
  onMonthChange,
  currentDate,
  HeaderComponent,
  DayLabelComponent,
  DayComponent,
  theme = {},
  monthBuffer = 1,
  minDate,
  maxDate,
  pageInterpolator = defaultPageInterpolator,
  simultaneousHandlers
}, ref) {
  const initialDateRef = (0, _react.useRef)(currentDate || new Date());
  const pagerRef = (0, _react.useRef)(null);
  const currentDateRef = (0, _react.useRef)(currentDate);
  const currentPageRef = (0, _react.useRef)(0);
  const minPageIndex = (0, _react.useMemo)(() => {
    if (!minDate) return -Infinity;
    return (0, _dateFns.differenceInCalendarMonths)(initialDateRef.current, minDate) * -1;
  }, [minDate]);
  const maxPageIndex = (0, _react.useMemo)(() => {
    if (!maxDate) return Infinity;
    return (0, _dateFns.differenceInCalendarMonths)(initialDateRef.current, maxDate) * -1;
  }, [maxDate]);
  const onMonthChangeRef = (0, _react.useRef)(onMonthChange);
  onMonthChangeRef.current = onMonthChange;
  const fullThemeObj = { ...DEFAULT_THEME,
    ...theme
  };
  const fullThemeRef = (0, _react.useRef)(fullThemeObj);
  const fullTheme = (0, _react.useMemo)(() => {
    const updatedTheme = { ...DEFAULT_THEME,
      ...theme
    };

    if ((0, _lodash.isEqual)(fullThemeRef.current, updatedTheme)) {
      return fullThemeRef.current;
    } else {
      fullThemeRef.current = updatedTheme;
      return updatedTheme;
    }
  }, [theme]);
  (0, _react.useImperativeHandle)(ref, () => ({
    incrementMonth: options => {
      var _options$animated, _pagerRef$current;

      const animated = (_options$animated = options === null || options === void 0 ? void 0 : options.animated) !== null && _options$animated !== void 0 ? _options$animated : true;
      (_pagerRef$current = pagerRef.current) === null || _pagerRef$current === void 0 ? void 0 : _pagerRef$current.incrementPage({
        animated
      });
    },
    decrementMonth: options => {
      var _options$animated2, _pagerRef$current2;

      const animated = (_options$animated2 = options === null || options === void 0 ? void 0 : options.animated) !== null && _options$animated2 !== void 0 ? _options$animated2 : true;
      (_pagerRef$current2 = pagerRef.current) === null || _pagerRef$current2 === void 0 ? void 0 : _pagerRef$current2.decrementPage({
        animated
      });
    },
    setMonth: (date, options) => {
      var _options$animated3, _pagerRef$current3;

      const animated = (_options$animated3 = options === null || options === void 0 ? void 0 : options.animated) !== null && _options$animated3 !== void 0 ? _options$animated3 : false;
      const page = (0, _dateFns.differenceInCalendarMonths)(date, initialDateRef.current);
      (_pagerRef$current3 = pagerRef.current) === null || _pagerRef$current3 === void 0 ? void 0 : _pagerRef$current3.setPage(page, {
        animated
      });
    }
  }), []);
  (0, _react.useEffect)(() => {
    if (currentDate && currentDateRef.current && !(0, _dateFns.isSameMonth)(currentDate, currentDateRef.current)) {
      var _pagerRef$current4;

      const page = (0, _dateFns.differenceInCalendarMonths)(currentDate, initialDateRef.current);
      if (page === currentPageRef.current) return;
      (_pagerRef$current4 = pagerRef.current) === null || _pagerRef$current4 === void 0 ? void 0 : _pagerRef$current4.setPage(page, {
        animated: false
      });
    }

    currentDateRef.current = currentDate;
  }, [currentDate]);
  const onPageChange = (0, _react.useCallback)(pg => {
    var _onMonthChangeRef$cur;

    currentPageRef.current = pg;
    const currentMonth = (0, _dateFns.addMonths)(initialDateRef.current, pg);
    currentMonth.setDate(1);
    (_onMonthChangeRef$cur = onMonthChangeRef.current) === null || _onMonthChangeRef$cur === void 0 ? void 0 : _onMonthChangeRef$cur.call(onMonthChangeRef, currentMonth);
  }, []);
  const providerValue = (0, _react.useMemo)(() => ({
    referenceDate: initialDateRef.current,
    selectedDate,
    onDateSelect,
    HeaderComponent,
    DayLabelComponent,
    DayComponent,
    theme: fullTheme,
    pageInterpolator
  }), [selectedDate, onDateSelect, HeaderComponent, DayLabelComponent, DayComponent, fullTheme, pageInterpolator]);
  const pageInterpolatorInternal = (0, _react.useCallback)(params => {
    "worklet";

    return pageInterpolator(Object.assign(params, {
      theme: fullTheme
    }));
  }, [fullTheme, pageInterpolator]);
  return /*#__PURE__*/_react.default.createElement(CalendarContext.Provider, {
    value: providerValue
  }, /*#__PURE__*/_react.default.createElement(_reactNativeInfinitePager.default, {
    ref: pagerRef,
    PageComponent: MonthPage,
    pageBuffer: monthBuffer,
    onPageChange: onPageChange,
    minIndex: minPageIndex,
    maxIndex: maxPageIndex,
    pageInterpolator: pageInterpolatorInternal,
    simultaneousHandlers: simultaneousHandlers
  }));
}

var _default = /*#__PURE__*/_react.default.memo( /*#__PURE__*/_react.default.forwardRef(Calendar));

exports.default = _default;

const styles = _reactNative.StyleSheet.create({
  flex: {
    flex: 1
  },
  row: {
    flexDirection: "row"
  },
  dayLabelContainer: {
    flex: 1,
    justifyContent: "center",
    alignItems: "center"
  },
  weekContainer: {
    flexDirection: "row",
    justifyContent: "space-between"
  },
  dayLabelRow: {
    flex: 1,
    flexDirection: "row",
    justifyContent: "space-between",
    paddingVertical: 10
  }
});
//# sourceMappingURL=index.js.map