import React from "react";
import { useAnimatedStyle } from "react-native-reanimated";
import { PageInterpolatorParams } from "react-native-infinite-pager";
declare type TextTransform = "uppercase" | "lowercase" | "capitalize" | "none";
declare const DEFAULT_THEME: {
    todayIndicatorDotColor: string;
    selectedDayBackgroundColor: string;
    selectedDayFontColor: string;
    headerFontFamily: string;
    headerFontColor: string;
    headerFontSize: number;
    headerTextTransform: TextTransform;
    headerDateFormat: string;
    dayLabelFontFamily: string;
    dayLabelColor: string;
    dayLabelFontSize: number;
    dayLabelTextTransform: TextTransform;
    dayLabelDateFormat: string;
    dayFontFamily: string;
    dayFontColor: string;
    dayInactiveFontColor: string;
    daySelectedFontColor: string;
    dayFontSize: number;
    inactiveOpacity: number;
};
declare type OnDateSelect = undefined | ((date: Date, options: {
    isSelected: boolean;
}) => void);
export declare type DayComponentType = (props: {
    date: Date;
    isInDisplayedMonth: boolean;
    isSelected: boolean;
    isToday: boolean;
}) => JSX.Element | null;
export declare type HeaderComponentType = (props: {
    date: Date;
}) => JSX.Element | null;
export declare type DayLabelComponentType = (props: {
    date: Date;
}) => JSX.Element | null;
declare type ImperativeApiOptions = {
    animated?: boolean;
};
export declare function useCalendarContext(): {
    referenceDate: Date;
    selectedDate: Date | null | undefined;
    onDateSelect: OnDateSelect;
    DayComponent: DayComponentType | undefined;
    DayLabelComponent: DayLabelComponentType | undefined;
    HeaderComponent: HeaderComponentType | undefined;
    theme: {
        todayIndicatorDotColor: string;
        selectedDayBackgroundColor: string;
        selectedDayFontColor: string;
        headerFontFamily: string;
        headerFontColor: string;
        headerFontSize: number;
        headerTextTransform: TextTransform;
        headerDateFormat: string;
        dayLabelFontFamily: string;
        dayLabelColor: string;
        dayLabelFontSize: number;
        dayLabelTextTransform: TextTransform;
        dayLabelDateFormat: string;
        dayFontFamily: string;
        dayFontColor: string;
        dayInactiveFontColor: string;
        daySelectedFontColor: string;
        dayFontSize: number;
        inactiveOpacity: number;
    };
    pageInterpolator: typeof defaultPageInterpolator;
};
export declare type CalendarPageInterpolatorParams = PageInterpolatorParams & {
    theme: typeof DEFAULT_THEME;
};
declare function defaultPageInterpolator({ focusAnim, theme, pageWidth, }: CalendarPageInterpolatorParams): ReturnType<typeof useAnimatedStyle>;
export declare const MonthPage: React.MemoExoticComponent<({ index }: {
    index: number;
}) => JSX.Element>;
export declare type CalendarImperativeApi = {
    incrementMonth: (options?: ImperativeApiOptions) => void;
    decrementMonth: (options?: ImperativeApiOptions) => void;
    setMonth: (date: Date, options?: ImperativeApiOptions) => void;
};
declare type CalendarProps = {
    selectedDate?: Date | null;
    onDateSelect?: OnDateSelect;
    onMonthChange?: (date: Date) => void;
    currentDate?: Date;
    HeaderComponent?: HeaderComponentType;
    DayLabelComponent?: DayLabelComponentType;
    DayComponent?: DayComponentType;
    theme?: Partial<typeof DEFAULT_THEME>;
    monthBuffer?: number;
    minDate?: Date;
    maxDate?: Date;
    pageInterpolator?: typeof defaultPageInterpolator;
    simultaneousHandlers?: React.Ref<unknown> | React.Ref<unknown>[];
};
declare const _default: React.MemoExoticComponent<React.ForwardRefExoticComponent<CalendarProps & React.RefAttributes<CalendarImperativeApi>>>;
export default _default;
